# csh plotP.com $file $title $type 
# Plot throughput as a function of the configured drop rate.
# Plot experiences drop rates.

# TO DO:  Add average and median throughput.
#         Add throughput as a function of drop rate.
#         Added expected throughput for this drop rate.
#         Look at the difference between loss rates and calculated
#               loss event rates?
set file=$1
set title=$2 
set type=$3
set tcppkt=$4
# set tfrcpkt=$5
set half=50
if ($type == "ps") then 
  set type1='postscript eps'
endif
if ($type == "png") then 
  set type1='png'
endif
## d3: TFRC Per-Flow Drop Rates, for Drop Parameter
## t1: Average per-flow sending rate for TCP traffic in Kbps,
##       second half of simulation.  Includes headers.
##     Aggregate throughput divided by number of flows.
## t2: Average per-flow sending rate for VoIP traffic in Kbps,
##       second half of simulation.  Includes headers.
##     Aggregate throughput divided by number of flows.
## t6: VoIP Data and Header Per-Flow Sending Rates in Kbps
## t7: TCP Data and Header Per-Flow Sending Rates in Kbps
## t8: Median of t6.
## t9: Median of t7.
## t10: Average of t6.
## t11: Average of t7.
## t12: Ideal sending rate, plugging packet drop rate into TCP equation,
##    maxed by max_rate
awk -f dropratesW.awk $file > d3
awk -f dropratesAggW.awk fid=5 $file > d5
awk -f dropratesAggW.awk fid=0 $file > d6
awk -f thPW.awk fid=0 $file > t1
awk -f thPW.awk fid=5 $file > t2
awk -f flowPW.awk $file > t6
awk -f flowPtcpW.awk tcppkt=$tcppkt $file > t7
sort t6 | awk -f medianP.awk total=5 > t8
sort t7 | awk -f medianP.awk total=5 > t9
awk -f avgP.awk t6 > t10
awk -f avgP.awk t7 > t11
gnuplot << !
set terminal $type1 
set xlabel "Number of Web Sessions"
set ylabel "Per-Flow Drop Rates"
set logscale y
set logscale x
set yrange [0.001:2]
set xrange [10:3500]
set title "$title"
set output "$file.$type"
set key left 
# set size 0.6,0.8
set size 1.0,0.8 
plot "d3" title "VoIP_drop_rates" with points pt 1 ps 1, \
"d5" title "VoIP_aggregate_drop_rate" with linespoints pt 3 ps 1, \
"d6" title "TCP_aggregate_drop_rate" with linespoints pt 4 ps 1
!
gnuplot << !
# set term post
set terminal $type1 
set xlabel "Number of Web Sessions"
set ylabel "Throughput (Kbps)"
set logscale y
set logscale x
set yrange [0.3:2000]
set xrange [10:3500]
set title "$title"
set output "$file.1.$type"
set key right 
# set size 0.6,0.8
set size 1.0,0.8 
plot "t6" title "TFRC_sending_rates_(with_headers)" with points pt 1 ps 1, \
"t7" title "TCP_sending_rates_(with_headers)" with points pt 2 ps 1, \
"t8" title "Median_TFRC_sending_rate" with linespoints pt 1 ps 1, \
"t9" title "Median_TCP_sending_rate" with linespoints pt 2 ps 1, \
"t10" title "Average_TFRC_sending_rate" with linespoints pt 1 ps 1, \
"t11" title "Average_TCP_sending_rate" with linespoints pt 2 ps 1
!
gnuplot << !
# set term post
set terminal $type1 
set xlabel "Number of Web Sessions"
set ylabel "Sending Rate (Kbps)"
set logscale y
set logscale x
set yrange [0.3:2000]
set xrange [10:3500]
set title "$title"
set output "$file.2.$type"
set key right 
# set size 0.6,0.8
set size 1.0,0.8 
plot "t1" title "Average_TCP_sending_rate" with linespoints pt 2 ps 1, \
"t2" title "Average_TFRC_sending_rate" with linespoints pt 1 ps 1
!
if ($type == "ps") then
  gv $file.ps &
  gv $file.1.ps &
  gv $file.2.ps &
endif
